@@ -10,13 +10,13 @@ from .pipe import Pype
 from .preprocessing import TargetRunLengthEncoder
 from .split import TemporalKFold, temporal_split
 from .transform import Segment, SegmentX, SegmentXY, SegmentXYForecast, PadTrunc, Interp, InterpLongToWide, \
-    FeatureRep, FeatureRepMix, FunctionTransformer, patch_sampler
+    FeatureRep, FeatureRepMix, FunctionTransformer
 from .util import check_ts_data, check_ts_data_with_ts_target, ts_stats, get_ts_data_parts
 
 __all__ = ['TS_Data', 'FeatureRep', 'FeatureRepMix', 'PadTrunc', 'Interp', 'InterpLongToWide', 'Pype', 'Segment',
            'SegmentX', 'SegmentXY', 'SegmentXYForecast', 'TemporalKFold', 'temporal_split', 'check_ts_data',
            'check_ts_data_with_ts_target', 'ts_stats', 'get_ts_data_parts', 'all_features',
            'base_features', 'load_watch', 'TargetRunLengthEncoder', 'FunctionTransformer',
-           'patch_sampler', '__version__']
+           '__version__']
 
 __author__ = 'David Burns david.mo.burns@gmail.com'
